
<template>
  <view-grid
    ref="grid"
    :columns="columns"
    :detail="detail"
    :editFormFields="editFormFields"
    :editFormOptions="editFormOptions"
    :searchFormFields="searchFormFields"
    :searchFormOptions="searchFormOptions"
    :table="table"
    :extend="extend"
  >
  </view-grid>
</template>
<script>
import extend from "@/extension/system/Sys_User.js";
import { ref, defineComponent } from "vue";
export default defineComponent({
  setup() {
    const table = ref({
      key: "user_Id",
      footer: "Foots",
      cnName: "用户管理",
      name: "Sys_User",
      url: "/User/",
      sortName: "user_Id",
    });
    const editFormFields = ref({
      systemType: "0",
      userName: "",
      userTrueName: "",
      role_Id: [],
      deptIds: "",
      enable: "",
      gender: "",
      remark: "",
      headImageUrl: "",
    });
    const editFormOptions = ref([
      [{ title: "帐号", required: true, field: "userName"}],
      [{ title: "姓名", required: true, field: "userTrueName", type: "text" }],
      [
        {
          dataKey: "tree_roles",
          data: [],
          title: "角色",
          required: true,
          field: "role_Id",
          type: "cascader",
        },
      ],
      // [
      //   {
      //     dataKey: "组织机构",
      //     data: [],
      //     title: "组织构架",
      //     field: "deptIds",
      //     colSize: 12,
      //     type: "treeSelect",
      //   },
      // ],
      [
        {
          dataKey: "enable",
          data: [],
          title: "是否可用",
          required: true,
          field: "enable",
          type: "select",
        },
      ],
      [
        {
          dataKey: "gender",
          data: [],
          title: "性别",
          field: "gender",
          type: "select",
        },
      ],
      [{ title: "备注", field: "remark", colSize: 12, type: "textarea" }],
      // [{ title: "头像", field: "headImageUrl", type: "img" }],
    ]);
    const searchFormFields = ref({
      systemType: "0",
      userName: "",
      userTrueName: "",
      gender: "",
      deptName: "",
      role_Id: [],
      token: "",
      appType: [],
      createDate: "",
      isRegregisterPhone: "",
      phoneNo: "",
      enable: "",
      lastLoginDate: "",
      address: "",
      email: "",
    });
    const searchFormOptions = ref([
      [
        { title: "帐号", field: "userName" },
        { title: "姓名", field: "userTrueName" },
        {
          dataKey: "gender",
          data: [],
          title: "性别",
          field: "gender",
          type: "select",
        },
      ],
      [
        {
          dataKey: "enable",
          data: [],
          title: "是否可用",
          field: "enable",
          type: "select",
        },
        { title: "注册时间", field: "createDate", type: "datetime" },
      ],
    ]);
    const columns = ref([
      {
        field: "user_Id",
        title: "User_Id",
        type: "int",
        width: 90,
        hidden: true,
        readonly: true,
        require: true,
        align: "left",
      },
      {
        field: "userName",
        title: "帐号",
        type: "string",
        link: true,
        width: 120,
        readonly: true,
        require: true,
        align: "left",
        sort: true,
      },
      {
        field: "userTrueName",
        title: "姓名",
        type: "string",
        width: 120,
        require: true,
        align: "left",
      },
      {
        field: "gender",
        title: "性别",
        type: "int",
        bind: { key: "gender", data: [] },
        width: 80,
        align: "left",
      },
      // {
      //   field: "headImageUrl",
      //   title: "头像",
      //   type: "img",
      //   width: 90,
      //   align: "left",
      // },
      {
        field: "dept_Id",
        title: "不用",
        type: "int",
        width: 90,
        hidden: true,
        align: "left",
      },
      {
        field: "deptName",
        title: "不用",
        type: "string",
        width: 150,
        hidden: true,
        align: "left",
      },
      {
        field: "role_Id",
        title: "角色",
        type: "int",
        bind: { key: "tree_roles", data: [] },
        width: 130,
        require: true,
        align: "left",
      },
      {
        field: "roleName",
        title: "不用",
        type: "string",
        width: 90,
        hidden: true,
        align: "left",
      },
      {
        field: "token",
        title: "Token",
        type: "string",
        width: 180,
        hidden: true,
        align: "left",
      },
      {
        field: "appType",
        title: "类型",
        type: "int",
        bind: { key: "ut", data: [] },
        width: 150,
        hidden: true,
        align: "left",
      },
      {
        field: "deptIds",
        title: "组织构架",
        type: "string",
        bind: { key: "组织机构", data: [] },
        width: 140,
        hidden: true,
        align: "left",
      },
      {
        field: "createDate",
        title: "注册时间",
        type: "datetime",
        width: 150,
        readonly: true,
        align: "left",
        sort: true,
      },
      {
        field: "phoneNo",
        title: "手机号",
        type: "string",
        width: 150,
        hidden: true,
        align: "left",
      },
      {
        field: "tel",
        title: "Tel",
        type: "string",
        width: 90,
        hidden: true,
        align: "left",
      },
      {
        field: "creater",
        title: "创建人",
        type: "string",
        width: 130,
        readonly: true,
        align: "left",
      },
      {
        field: "enable",
        title: "是否可用",
        type: "byte",
        bind: { key: "enable", data: [] },
        width: 90,
        require: true,
        align: "left",
      },
      {
        field: "modifier",
        title: "修改人",
        type: "string",
        width: 130,
        hidden: true,
        readonly: true,
        align: "left",
      },
      {
        field: "modifyDate",
        title: "修改时间",
        type: "datetime",
        width: 90,
        hidden: true,
        readonly: true,
        align: "left",
        sort: true,
      },
      {
        field: "auditStatus",
        title: "审核状态",
        type: "int",
        bind: { key: "audit", data: [] },
        width: 90,
        hidden: true,
        align: "left",
      },
      {
        field: "auditor",
        title: "审核人",
        type: "string",
        width: 90,
        hidden: true,
        align: "left",
      },
      {
        field: "auditDate",
        title: "审核时间",
        type: "datetime",
        width: 150,
        hidden: true,
        align: "left",
        sort: true,
      },
      {
        field: "lastModifyPwdDate",
        title: "最后密码修改时间",
        type: "datetime",
        width: 150,
        hidden: true,
        align: "left",
        sort: true,
      },
      {
        field: "address",
        title: "地址",
        type: "string",
        width: 190,
        hidden: true,
        align: "left",
      },
      {
        field: "email",
        title: "Email",
        type: "string",
        width: 140,
        hidden: true,
        align: "left",
      },
      {
        field: "remark",
        title: "备注",
        type: "string",
        width: 180,
        hidden: true,
        align: "left",
      },
    ]);
    const detail = ref({
      cnName: "#detailCnName",
      table: "#detailTable",
      columns: [],
      sortName: "",
      key: "",
    });
    return {
      table,
      extend,
      editFormFields,
      editFormOptions,
      searchFormFields,
      searchFormOptions,
      columns,
      detail,
    };
  },
});
</script>
